@@ -451,7 +451,7 @@ int32_t service_ldap_init(char *ip, int32_t sp, unsigned char options, char *mis
   // return codes:
   //   0 all OK
   //   -1  error, hydra will exit, so print a good error message here
-  if (strlen(miscptr) > 220) {
+  if (miscptr != NULL && strlen(miscptr) > 220) {
     fprintf(stderr, "[ERROR] the option string to this module may not be larger than 220 bytes\n");
     return -1;
   }
@@ -466,6 +466,6 @@ void usage_ldap(const char* service) {
          "Special notes for Simple method has 3 operation modes: anonymous, (no user no pass),\n"
          "unauthenticated (user but no pass), user/pass authenticated (user and pass).\n"
          "So don't forget to set empty string as user/pass to test all modes.\n"
-         "Hint: to authenticate to a windows active directy ldap, this is usually\n"
+         "Hint: to authenticate to a windows active directory ldap, this is usually\n"
          " cn=^USER^,cn=users,dc=foo,dc=bar,dc=com for domain foo.bar.com\n\n", service);
 }
