@@ -3,11 +3,12 @@
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
+#include <stdint.h>
 
 #define PROGRAM		"PW-Inspector"
 #define VERSION		"v0.2"
 #define EMAIL		"vh@thc.org"
-#define WEB		"http://www.thc.org"
+#define WEB		"https://github.com/vanhauser-thc/thc-hydra"
 
 #define MAXLENGTH	256
 
@@ -36,7 +37,7 @@ void help() {
   exit(-1);
 }
 
-int32_t main(int32_t argc, char *argv[]) {
+int main(int argc, char *argv[]) {
   int32_t i, j, k;
   int32_t sets = 0, countsets = 0, minlen = 0, maxlen = MAXLENGTH, count = 0;
   int32_t set_low = 0, set_up = 0, set_no = 0, set_print = 0, set_other = 0;
